@@ -47,7 +47,14 @@
 -- 1 - the given name is invalid. */
 
 int glp_get_cpar(char *name, char *val)
-{     if (strcmp(name, "mps_bnd_name") == 0)
+{     if (strcmp(name, "fn_gener") == 0)
+      {  /* file name to output generated LP/MIP problem */
+         if (glp->fn_gener == NULL)
+            val[0] = '\0';
+         else
+            get_str(val, glp->fn_gener);
+      }
+      else if (strcmp(name, "mps_bnd_name") == 0)
       {  /* the name of bound vector */
          strcpy(val, glp->mps_bnd_name);
       }
