@@ -25,7 +25,7 @@
 
 #include <stddef.h>
 #include "glpk.h"
-#include "glpmip.h"
+#include "glpbbm.h"
 #include "glprsm.h"
 
 /*----------------------------------------------------------------------
@@ -90,7 +90,7 @@ int glp_integer(void)
       LPSOL *sol = NULL;
       struct rsm1_cp rsm_cp;
       int m, n, option, form, branch, btrack, ret;
-      struct mip1_cp mip_cp;
+      struct bbm1_cp bbm_cp;
       /* extract LP problem data from the workspace */
       lp = extract_lp();
       if (lp == NULL)
@@ -138,43 +138,43 @@ int glp_integer(void)
       /* set control parameters */
       glp_get_ipar("option", &option);
       switch (option)
-      {  case GLP_INI:     mip_cp.what = 0; break;
-         case GLP_ANY:     mip_cp.what = 1; break;
-         case GLP_FIN:     mip_cp.what = 2; break;
+      {  case GLP_INI:     bbm_cp.what = 0; break;
+         case GLP_ANY:     bbm_cp.what = 1; break;
+         case GLP_FIN:     bbm_cp.what = 2; break;
          default:          insist(option != option);
       }
       glp_get_ipar("mip_branch", &branch);
       switch (branch)
-      {  case GLP_FIRST:   mip_cp.branch = BB_FIRST; break;
-         case GLP_LAST:    mip_cp.branch = BB_LAST;  break;
-         case GLP_DRTOM:   mip_cp.branch = BB_DRTOM; break;
+      {  case GLP_FIRST:   bbm_cp.branch = BB_FIRST; break;
+         case GLP_LAST:    bbm_cp.branch = BB_LAST;  break;
+         case GLP_DRTOM:   bbm_cp.branch = BB_DRTOM; break;
          default:          insist(branch != branch);
       }
       glp_get_ipar("mip_btrack", &btrack);
       switch (btrack)
-      {  case GLP_FIFO:    mip_cp.btrack = BB_FIFO;  break;
-         case GLP_LIFO:    mip_cp.btrack = BB_LIFO;  break;
-         case GLP_BESTP:   mip_cp.btrack = BB_BESTP; break;
+      {  case GLP_FIFO:    bbm_cp.btrack = BB_FIFO;  break;
+         case GLP_LIFO:    bbm_cp.btrack = BB_LIFO;  break;
+         case GLP_BESTP:   bbm_cp.btrack = BB_BESTP; break;
          default:          insist(btrack != btrack);
       }
-      glp_get_rpar("tol_int", &mip_cp.tol_int);
-      glp_get_rpar("tol_obj", &mip_cp.tol_obj);
+      glp_get_rpar("tol_int", &bbm_cp.tol_int);
+      glp_get_rpar("tol_obj", &bbm_cp.tol_obj);
       glp_get_ipar("spx_form", &form);
       switch (form)
-      {  case GLP_EFI:     mip_cp.form = 0; break;
-         case GLP_RFI_BG:  mip_cp.form = 1; break;
-         case GLP_RFI_FT:  mip_cp.form = 2; break;
+      {  case GLP_EFI:     bbm_cp.form = 0; break;
+         case GLP_RFI_BG:  bbm_cp.form = 1; break;
+         case GLP_RFI_FT:  bbm_cp.form = 2; break;
          default:          insist(form != form);
       }
-      glp_get_ipar("spx_steep", &mip_cp.steep);
-      glp_get_ipar("spx_relax", &mip_cp.relax);
-      glp_get_rpar("tol_bnd", &mip_cp.tol_bnd);
-      glp_get_rpar("tol_dj", &mip_cp.tol_dj);
-      glp_get_rpar("tol_piv", &mip_cp.tol_piv);
-      mip_cp.iter_max = 0;
-      glp_get_ipar("round", &mip_cp.round);
+      glp_get_ipar("spx_steep", &bbm_cp.steep);
+      glp_get_ipar("spx_relax", &bbm_cp.relax);
+      glp_get_rpar("tol_bnd", &bbm_cp.tol_bnd);
+      glp_get_rpar("tol_dj", &bbm_cp.tol_dj);
+      glp_get_rpar("tol_piv", &bbm_cp.tol_piv);
+      bbm_cp.iter_max = 0;
+      glp_get_ipar("round", &bbm_cp.round);
       /* solve MIP problem by means of branch-and-bound method */
-      ret = mip1_driver(lp, sol, &mip_cp);
+      ret = bbm1_driver(lp, sol, &bbm_cp);
       /* store solution back to the workspace */
       store_lpsol(sol);
       /* check if the integer problem has been solved successfully */
