@@ -48,7 +48,19 @@
 -- 2 - the given value is invalid. */
 
 int glp_set_ipar(char *name, int val)
-{     if (strcmp(name, "mps_one_entry") == 0)
+{     if (strcmp(name, "mip_branch") == 0)
+      {  /* branching technique flag */
+         if (!(val == GLP_FIRST || val == GLP_LAST || val == GLP_DRTOM))
+            return 2;
+         glp->mip_branch = val;
+      }
+      else if (strcmp(name, "mip_btrack") == 0)
+      {  /* backtracking technique flag */
+         if (!(val == GLP_FIFO || val == GLP_LIFO || val == GLP_BESTP))
+            return 2;
+         glp->mip_btrack = val;
+      }
+      else if (strcmp(name, "mps_one_entry") == 0)
       {  /* write MPS file not using fields 5 and 6 */
          if (!(val == GLP_NO || val == GLP_YES)) return 2;
          glp->mps_one_entry = val;
@@ -70,10 +82,15 @@ int glp_set_ipar(char *name, int val)
       }
       else if (strcmp(name, "obj_dir") == 0)
       {  /* optimization direction flag */
-         if (!(val == GLP_INI || val == GLP_ANY ||
-               val == GLP_MIN || val == GLP_MAX)) return 2;
+         if (!(val == GLP_MIN || val == GLP_MAX)) return 2;
          glp->obj_dir = val;
       }
+      else if (strcmp(name, "option") == 0)
+      {  /* what solution should be found by the solver */
+         if (!(val == GLP_INI || val == GLP_ANY || val == GLP_FIN))
+            return 2;
+         glp->option = val;
+      }
       else if (strcmp(name, "round") == 0)
       {  /* round the computed values of basis variable */
          if (!(val == GLP_NO || val == GLP_YES)) return 2;
@@ -109,7 +126,9 @@ int glp_set_ipar(char *name, int val)
       {  /* status of the computed solution (set bythe solver) */
          if (!(val == GLP_UNDEF  || val == GLP_OPT    ||
                val == GLP_FEAS   || val == GLP_INFEAS ||
-               val == GLP_NOFEAS || val == GLP_UNBND)) return 2;
+               val == GLP_NOFEAS || val == GLP_UNBND  ||
+               val == GLP_INTOPT || val == GLP_INTSOL ||
+               val == GLP_DISINT || val == GLP_NOINT)) return 2;
          glp->status = val;
       }
       else if (strcmp(name, "sum_aij") == 0)
