@@ -279,7 +279,7 @@ static int read_card(void)
          if (c == '\n') break;
          if (iscntrl(c))
          {  error("%s:%d: invalid control character 0x%02X", fname,
-               seqn);
+               seqn, c);
             return 1;
          }
          if (k == 80)
