@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <errno.h>
 #include <stdio.h>
 #include <string.h>
@@ -112,7 +111,7 @@ int save_as_tiff(IMG *img, char *fname)
          case IMG_4:    put_dword(fp, 4); break;
          case IMG_16:   put_dword(fp, 4); break;
          case IMG_256:  put_dword(fp, 8); break;
-         default: assert(img->type != img->type);
+         default: insist(img->type != img->type);
       }
       /* compression */
       put_word(fp, 0x0103);
@@ -168,7 +167,7 @@ int save_as_tiff(IMG *img, char *fname)
             put_dword(fp, img->xsize * img->ysize);
             break;
          default:
-            assert(img->type != img->type);
+            insist(img->type != img->type);
       }
       /* horizontal resolution */
       put_word(fp, 0x011A);
@@ -200,7 +199,7 @@ int save_as_tiff(IMG *img, char *fname)
          case IMG_4:    put_dword(fp, 3 * 16);  break;
          case IMG_16:   put_dword(fp, 3 * 16);  break;
          case IMG_256:  put_dword(fp, 3 * 256); break;
-         default: assert(img->type != img->type);
+         default: insist(img->type != img->type);
       }
       loc_0140 = ftell(fp);
       put_dword(fp, 0 /* will be stored later */);
@@ -284,7 +283,7 @@ int save_as_tiff(IMG *img, char *fname)
             }
             break;
          default:
-            assert(img->type != img->type);
+            insist(img->type != img->type);
       }
       /* strip data (pixels) */
       temp = ftell(fp);
@@ -326,7 +325,7 @@ int save_as_tiff(IMG *img, char *fname)
             }
             break;
          default:
-            assert(img->type != img->type);
+            insist(img->type != img->type);
       }
       fflush(fp);
       if (ferror(fp))
