@@ -395,25 +395,26 @@ SPAR *selection(SPAR *x, SPAR *y)
 SPAR *comparison(int op, SPAR *x, SPAR *y)
 {     MEMB *memb, *temp;
       EXPR *expr;
-      double cond;
+      double val, cond;
       if (!(x->type == 'X' || y->type == 'X'))
 err:     fatal("invalid operand of relation operation");
-      /* each member of both operands should be constant expression */
+      /* each members of the first operand should be a constant model
+         expression */
       for (memb = x->first; memb != NULL; memb = memb->next)
       {  expr = memb->link;
          insist(expr != NULL);
          if (!(expr->head->op == C_CON && expr->head->next == NULL))
             goto err;
       }
-      for (memb = y->first; memb != NULL; memb = memb->next)
-      {  expr = memb->link;
-         insist(expr != NULL);
-         if (!(expr->head->op == C_CON && expr->head->next == NULL))
-            goto err;
-      }
-      /* x := x - y */
-      x = addition(C_SUB, x, y);
-      /* x := x op 0 */
+      /* the second operand should be scalar, the only member of which
+         should be a constant expression */
+      if (!(y->dim == 0 && y->first != NULL && y->first->next == NULL))
+         goto err;
+      expr = y->first->link;
+      if (!(expr->head->op == C_CON && expr->head->next == NULL))
+         goto err;
+      val = expr->head->arg.con;
+      /* x := x op y */
       switch (op)
       {  case C_LT:
             strcpy(x->name, "<less than>");
@@ -445,7 +446,7 @@ err:     fatal("invalid operand of relation operation");
          expr = memb->link;
          insist(expr != NULL);
          insist(expr->head->op == C_CON && expr->head->next == NULL);
-         cond = eval_const(op, expr->head->arg.con, 0.0);
+         cond = eval_const(op, expr->head->arg.con, val);
          erase_expr(expr);
          memb->link = NULL;
          memb->next = NULL;
