@@ -37,7 +37,7 @@
 -- *Description*
 --
 -- The free_mps routine frees all memory allocated to the object of MPS
--- type thst represents linear programming model in the MPS format. */
+-- type that represents linear programming model in the MPS format. */
 
 void free_mps(MPS *mps)
 {       delete_pool(mps->pool);
