@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <string.h>
 #include "glpstr.h"
 
@@ -57,13 +56,13 @@ int compare_str(STR *str1, STR *str2)
          char buf1[SQE_SIZE], buf2[SQE_SIZE];
          memset(buf1, '\0', SQE_SIZE);
          if (n1 > 0)
-         {  assert(sqe1 != NULL);
+         {  insist(sqe1 != NULL);
             memcpy(buf1, sqe1->data, n1);
             len1 -= n1, sqe1 = sqe1->next;
          }
          memset(buf2, '\0', SQE_SIZE);
          if (n2 > 0)
-         {  assert(sqe2 != NULL);
+         {  insist(sqe2 != NULL);
             memcpy(buf2, sqe2->data, n2);
             len2 -= n2, sqe2 = sqe2->next;
          }
