@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <string.h>
 #include "glpstr.h"
 
@@ -52,7 +51,7 @@ char *get_str(char *to, STR *str)
       char *ptr = to;
       for (sqe = str->head; len > 0; sqe = sqe->next)
       {  int n = (len <= SQE_SIZE ? len : SQE_SIZE);
-         assert(sqe != NULL);
+         insist(sqe != NULL);
          memcpy(ptr, sqe->data, n);
          ptr += n, len -= n;
       }
