@@ -84,8 +84,8 @@ typedef struct ADAT ADAT;
 
 struct ADAT
 {     /* Cholesky factorization of symmetric positive definite matrix
-         S = A*D*A', where A is rectangular matrix (of complete rank),
-         D is diagonal matrix; no dense columns processing */
+         S = A*D*A', where A is rectangular matrix (of full rank), D is
+         diagonal matrix; no dense columns processing */
       int m;
       /* number of rows of A */
       int n;
