@@ -75,7 +75,7 @@
 
 #define GLP_FIFO     801   /* backtrack using FIFO strategy */
 #define GLP_LIFO     802   /* backtrack using LIFO strategy */
-#define GLP_BESTP    803   /* backtracj using best projection heur */
+#define GLP_BESTP    803   /* backtrack using best projection heur */
 
 #define GLP_D_PARS   0x01  /* dump control parameters */
 #define GLP_D_ROWS   0x10  /* dump rows */
@@ -151,6 +151,9 @@ extern int glp_next_item(int what);
 extern int glp_print_sol(char *fname);
 /* write problem solution using printable format */
 
+extern int glp_read_lpm(char *fname);
+/* read problem data using LPM format */
+
 extern int glp_read_mps(char *fname);
 /* read problem data using MPS format */
 
