@@ -26,7 +26,7 @@
 #ifndef _GLPMPS_H
 #define _GLPMPS_H
 
-#include "glpprob.h"
+#include "glplp.h"
 
 #define load_mps              glp_load_mps
 #define free_mps              glp_free_mps
