@@ -27,7 +27,7 @@
 #define _GLPRSM_H
 
 #include "glpefi.h"
-#include "glpprob.h"
+#include "glplp.h"
 #include "glprfi.h"
 
 #define btran                 glp_btran
